FlanaBot
========

|license| |project_version| |python_version|

Flanagan's bot.

Installation
------------

Python 3.10 or higher is required.

.. code-block::

    pip install flanabot


.. |license| image:: https://img.shields.io/github/license/AlberLC/flanabot?style=flat
    :target: https://github.com/AlberLC/flanabot/blob/main/LICENSE
    :alt: License

.. |project_version| image:: https://img.shields.io/pypi/v/flanabot
    :target: https://pypi.org/project/flanabot/
    :alt: PyPI

.. |python_version| image:: https://img.shields.io/pypi/pyversions/flanabot
    :target: https://www.python.org/downloads/
    :alt: PyPI - Python Version